==> uke-admin-web-scaffold-1.2.0-rc8.tgz: package/action-agent/index.js <==
/* eslint-disable class-methods-use-this */
/**
 * 基础 Action 组件, 主要实现了请求方式, 包含表单验证的方式
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
import { Component } from 'react';
import { Call, IsFunc, DebounceClass } from 'basic-helper';
import { getUrlParams } from 'uke-request/url-resolve';
var ActionAgent = /** @class */ (function (_super) {
    __extends(ActionAgent, _super);
    function ActionAgent() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.getUrlParams = getUrlParams;
        _this.routerParams = getUrlParams();
        _this.agents = [];
        return _this;
    }
    ActionAgent.prototype.componentWillUnmount = function () {
        this.__unmount = true;
        // setTimeout(() => {
        //   console.log(this.reqInstance);
        // }, 100);
    };
    /**
     * 请求过程的 state 状态代理
     * @param {reqFunc} asyncFunc 业务 API
     * @param {agentOptions} object 此方法的配置项
     * @return {async function} 返回传入的第一个参数的包装方法，在此过程插入一些生命周期函数
     */
    ActionAgent.prototype.reqAgent = function (reqFunc, agentOptions) {
        var _this = this;
        if (!IsFunc(reqFunc)) {
            var errMsg = 'should pass func at arguments[0]';
            throw Error(errMsg);
        }
        var _a = agentOptions.id, id = _a === void 0 ? 'reqAction' : _a, _b = agentOptions.actingRef, actingRef = _b === void 0 ? 'loading' : _b, before = agentOptions.before, after = agentOptions.after, resFilter = agentOptions.resFilter;
        this.stateSetter(this._before(Call(before), actingRef));
        return function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            return new Promise(function (resolve, reject) { return __awaiter(_this, void 0, void 0, function () {
                var res, e_1, _a, _b, _c, _d, _e, _f, result;
                var _g;
                return __generator(this, function (_h) {
                    switch (_h.label) {
                        case 0:
                            res = {};
                            _h.label = 1;
                        case 1:
                            _h.trys.push([1, 3, , 4]);
                            return [4 /*yield*/, reqFunc.apply(void 0, args)];
                        case 2:
                            res = _h.sent();
                            return [3 /*break*/, 4];
                        case 3:
                            e_1 = _h.sent();
                            console.log(e_1);
                            res.err = e_1;
                            return [3 /*break*/, 4];
                        case 4:
                            if (!IsFunc(after)) {
                                throw Error('after should be a function');
                            }
                            _a = this.stateSetter;
                            _c = (_b = Object).assign;
                            _d = [{}, (_g = {},
                                    _g[actingRef] = false,
                                    _g), this._after(res)];
                            if (!this._checkRes(res)) return [3 /*break*/, 7];
                            _f = after;
                            if (!_f) return [3 /*break*/, 6];
                            return [4 /*yield*/, after(res)];
                        case 5:
                            _f = (_h.sent());
                            _h.label = 6;
                        case 6:
                            _e = (_f);
                            return [3 /*break*/, 8];
                        case 7:
                            _e = {};
                            _h.label = 8;
                        case 8:
                            _a.apply(this, [_c.apply(_b, _d.concat([_e]))]);
                            this.resStatus(res, id);
                            result = resFilter ? resFilter(res) : res;
                            resolve(result);
                            return [2 /*return*/];
                    }
                });
            }); });
        };
    };
    ActionAgent.prototype._before = function (params, actingRef) {
        var _a;
        return Object.assign({}, (_a = {},
            _a[actingRef] = true,
            _a), params);
    };
    ActionAgent.prototype._after = function (res) {
        return {};
    };
    /**
     * 在调用 after 之前执行的 checker 函数
     * @param {response} res 系统传入的 res 对象
     * @return {boolean}
     */
    ActionAgent.prototype._checkRes = function (res) {
        return true;
    };
    ActionAgent.prototype.resStatus = function (res, id) {
    };
    ActionAgent.prototype.delayExec = function () {
        var _a;
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        if (!this._delayExec)
            this._delayExec = new DebounceClass();
        return (_a = this._delayExec).exec.apply(_a, args);
    };
    ActionAgent.prototype.stateSetter = function (state) {
        if (!this.__unmount && this.setState)
            this.setState(state);
    };
    return ActionAgent;
}(Component));
export default ActionAgent;

==> uke-admin-web-scaffold-1.2.4.tgz: package/action-agent/index.js <==
/* eslint-disable class-methods-use-this */
/**
 * 基础 Action 组件, 主要实现了请求方式, 包含表单验证的方式
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
import { Component } from 'react';
import { Call, IsFunc, DebounceClass } from 'basic-helper';
import { getUrlParams } from 'uke-request/url-resolve';
var ActionAgent = /** @class */ (function (_super) {
    __extends(ActionAgent, _super);
    function ActionAgent() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.getUrlParams = getUrlParams;
        _this.routerParams = getUrlParams();
        _this.agents = [];
        return _this;
    }
    ActionAgent.prototype.componentWillUnmount = function () {
        this.__unmount = true;
        // setTimeout(() => {
        //   console.log(this.reqInstance);
        // }, 100);
    };
    /**
     * 请求过程的 state 状态代理
     * @param {reqFunc} asyncFunc 业务 API
     * @param {agentOptions} object 此方法的配置项
     * @return {async function} 返回传入的第一个参数的包装方法，在此过程插入一些生命周期函数
     */
    ActionAgent.prototype.reqAgent = function (reqFunc, agentOptions) {
        var _this = this;
        if (!IsFunc(reqFunc)) {
            var errMsg = 'should pass func at arguments[0]';
            throw Error(errMsg);
        }
        var _a = agentOptions.id, id = _a === void 0 ? 'reqAction' : _a, _b = agentOptions.actingRef, actingRef = _b === void 0 ? 'loading' : _b, before = agentOptions.before, after = agentOptions.after, resFilter = agentOptions.resFilter;
        this.stateSetter(this._before(Call(before), actingRef));
        return function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            return new Promise(function (resolve, reject) { return __awaiter(_this, void 0, void 0, function () {
                var res, e_1, _a, _b, _c, _d, _e, _f, result;
                var _g;
                return __generator(this, function (_h) {
                    switch (_h.label) {
                        case 0:
                            _h.trys.push([0, 2, , 3]);
                            return [4 /*yield*/, reqFunc.apply(void 0, args)];
                        case 1:
                            res = _h.sent();
                            return [3 /*break*/, 3];
                        case 2:
                            e_1 = _h.sent();
                            console.log(e_1);
                            res.err = e_1;
                            return [3 /*break*/, 3];
                        case 3:
                            // if (!IsFunc(after)) {
                            //   throw Error('after should be a function');
                            // }
                            _a = this.stateSetter;
                            _c = (_b = Object).assign;
                            _d = [{}, (_g = {},
                                    _g[actingRef] = false,
                                    _g), this._after(res)];
                            if (!this._checkRes(res)) return [3 /*break*/, 6];
                            _f = IsFunc(after);
                            if (!_f) return [3 /*break*/, 5];
                            return [4 /*yield*/, after(res)];
                        case 4:
                            _f = (_h.sent());
                            _h.label = 5;
                        case 5:
                            _e = (_f);
                            return [3 /*break*/, 7];
                        case 6:
                            _e = {};
                            _h.label = 7;
                        case 7:
                            // if (!IsFunc(after)) {
                            //   throw Error('after should be a function');
                            // }
                            _a.apply(this, [_c.apply(_b, _d.concat([_e]))]);
                            this.resStatus(res, id);
                            result = resFilter ? resFilter(res) : res;
                            resolve(result);
                            return [2 /*return*/];
                    }
                });
            }); });
        };
    };
    ActionAgent.prototype._before = function (params, actingRef) {
        var _a;
        return Object.assign({}, (_a = {},
            _a[actingRef] = true,
            _a), params);
    };
    ActionAgent.prototype._after = function (res) {
        return {};
    };
    /**
     * 在调用 after 之前执行的 checker 函数
     * @param {response} res 系统传入的 res 对象
     * @return {boolean}
     */
    ActionAgent.prototype._checkRes = function (res) {
        return true;
    };
    ActionAgent.prototype.resStatus = function (res, id) {
    };
    ActionAgent.prototype.delayExec = function () {
        var _a;
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        if (!this._delayExec)
            this._delayExec = new DebounceClass();
        return (_a = this._delayExec).exec.apply(_a, args);
    };
    ActionAgent.prototype.stateSetter = function (state) {
        if (!this.__unmount && this.setState)
            this.setState(state);
    };
    return ActionAgent;
}(Component));
export default ActionAgent;
